@@ -115,12 +115,20 @@ def parse_bool(arg: str) -> bool:
 # ______________________________________________________________________________________________________________________
 
 
-def input_prompt(name: str, choices: tuple = (None, ), default: object = None, enum: bool = False) -> object:
+def input_prompt(
+        name: str,
+        message: str = None,
+        choices: tuple = (None, ),
+        default: object = None,
+        enum: bool = False
+) -> object:
     """
     wrapper for pythons input() with choices, default value and continuous prompting if an invalid input was supplied
 
     Args:
         name: the name of the variable
+        message: the custom message to be printed.
+                    If not None, name is omitted, else `please set the {name}:` will be printed
         choices: the allowed values for input. If None, anything can be input
         default: the default value. If None, the user will continue to be prompted
         enum: enumerate the choices and allow for numerical input
@@ -129,7 +137,10 @@ def input_prompt(name: str, choices: tuple = (None, ), default: object = None, e
         user input
     """
 
-    print(f'please set the {name}:')
+    if message is not None:
+        print(f'{message}:')
+    else:
+        print(f'please set the {name}:')
     inp = None
     if choices == (None, ) and default is None:
         inp = input()
@@ -159,12 +170,13 @@ def input_prompt(name: str, choices: tuple = (None, ), default: object = None, e
 # ______________________________________________________________________________________________________________________
 
 
-def prompt_file_name(open_or_save: str = 'open') -> str:
+def prompt_file_name(open_or_save: str = 'open', gui: bool = True) -> str:
     """
     Prompts the user to select a file.
 
     Args:
         open_or_save: whether it should prompt for an existing file (open) or to save a new file (save)
+        gui: whether to use tkinter gui or just plain input
 
     Returns:
         the path to the file
@@ -173,13 +185,17 @@ def prompt_file_name(open_or_save: str = 'open') -> str:
     if open_or_save not in ('open', 'save'):
         raise ValueError(f"Argument open_or_save must be 'open' or 'save'. Input was {open_or_save}")
 
-    if not runs_in_repl_mode():
+    if gui:
+        import tkinter as tk
+        window = tk.Tk()
+        window.wm_attributes('-topmost', 1)
+        window.withdraw()
         if open_or_save == 'open':
             from tkinter.filedialog import askopenfilename
-            file_path = askopenfilename(title='please select the file name')
+            file_path = askopenfilename(parent=window, title='please select the file name')
         elif open_or_save == 'save':
             from tkinter.filedialog import asksaveasfilename
-            file_path = asksaveasfilename(title='please set the file name to be saved')
+            file_path = asksaveasfilename(parent=window, title='please set the file name to be saved')
     else:
         file_path = str(input_prompt(name='path/to/file'))
         if open_or_save == 'open' and not Path(file_path).exists():
